# acheeve

The repository coordinates multiple chembees. 
A reminder: A chembee object manifests itself through 
the below shown SOLID design pattern. 

Thus, the `acheeve` object handles multiple chembees, for example to evaluate an algorithm: 

![Pattern](acheeve.png)